@@ -5,7 +5,7 @@ import unittest
 from iwf.client import Client
 from iwf.command_results import CommandResults
 from iwf.communication import Communication
-from iwf.iwf_api.iwf_api.models import RetryPolicy
+from iwf.iwf_api.models import RetryPolicy
 from iwf.persistence import Persistence
 from iwf.state_decision import StateDecision
 from iwf.state_schema import StateSchema
